// https://developers.google.com/maps/documentation/javascript/datalayer

var mediasPath = null;
var myMap;

function callbackJSON(features) {
	// centre la carte et met à jour l'url des icônes
	var lngMin, lngMax, latMin, latMax;

	for (i=0; i<features.length; i++) {
		var iconPath = features[i].getProperty('icon');
		if (iconPath !== undefined) {
			features[i].setProperty('icon', mediasPath + iconPath);
			console.log('icon: '+mediasPath + iconPath);
		}
		var geo = features[i].getGeometry();
		if (geo.getType() == 'Point') {
			var latLng = geo.get();
			if (latLng) {
				if ((!lngMin) || (lngMin > latLng.lng()))
					lngMin = latLng.lng();
				if ((!lngMax) || (lngMax < latLng.lng()))
					lngMax = latLng.lng();
				if ((!latMin) || (latMin > latLng.lat()))
					latMin = latLng.lat();
				if ((!latMax) || (latMax < latLng.lat()))
					latMax = latLng.lat();
			}
		}

	}
	myMap.panToBounds(
		new google.maps.LatLngBounds(
			{lat: latMin, lng: lngMin},
			{lat: latMax, lng: lngMax}
		)
	);
	myMap.setCenter({lat: (latMin + latMax)/ 2, lng: (lngMin + lngMax)/ 2});
}

function initMap() {

	var mainDiv = document.getElementById('main');
	if (mainDiv !== null) {
		mediasPath = mainDiv.getAttribute('data-root');
		if (mediasPath !== null) {
			var element = document.getElementById('myMap');

			if (element !== null) {
				var jsonPath = element.getAttribute('data-json');
				if (jsonPath !== null) {
					var coordsCenter = element.getAttribute('data-center');
					if (coordsCenter !== null) {
						var coords = coordsCenter.split(',');
						var latLngCenter = {
							lat: parseFloat(coords[0]),
							lng: parseFloat(coords[1])
						}
						var zoom = element.getAttribute('data-zoom');
						if (zoom !== null)
							zoom = parseInt(zoom)
						else
							zoom = 16;
						var mapOptions = {
							center: latLngCenter,
							zoom: zoom,
							panControl: false,
							mapTypeId: google.maps.MapTypeId.HYBRID,
							zoomControlOptions: {
						      style: google.maps.ZoomControlStyle.SMALL
						    },
							mapTypeControl:true,
						    mapTypeControlOptions: {
								style: google.maps.MapTypeControlStyle.DROPDOWN_MENU,
								position: google.maps.ControlPosition.TOP_CENTER
							},
							fullscreenControl: true
						};

						myMap = new google.maps.Map(element, mapOptions);
						// myMap.data.loadGeoJson(mediasPath + jsonPath, 'id', callbackJSON);
						myMap.data.loadGeoJson(mediasPath + jsonPath, 'id');

						myMap.data.setStyle(
							function(feature) {
								var props = [
									'clickable', 'visible', 'zIndex', // for all
									'cursor', 'icon', 'shape', 'title', // for point
									'strokeColor', 'strokeOpacity', 'strokeWeight', // for line|polyline
									'fillColor', 'fillOpacity' // for polyline:
									]
								// default values
								var resp = {};
								for (i=0; i<props.length; i++) {
									var name = props[i];
									var prop = feature.getProperty(name);
									if (prop) {
										if (name == 'icon')
											resp[name] = mediasPath + prop
										else
											resp[name] = prop;
									}
								}
								return resp;
							}
						);

						myMap.data.addListener('click',
							function(event) {
								var geometry = event.feature.getGeometry();
								var position = geometry.get()
								if (position) {
									var options = {
										'content': event.feature.getProperty('title')+ '<br />' + event.feature.getProperty('description'),
										'position': position
										}
									var info = new google.maps.InfoWindow(options);
									info.open(myMap);
								} else
									console.log(event.feature.getProperty('description'));
						});
					} else
						console.log('Element with id="main" has not attribute "data-center"');
				} else
					console.log('Url for the geoJSON file not set\n(attribut data-json is missing in div tag.)');
			} else
				console.log('Div element with id: myMap not found');
		} else
			console.log('Element with id="main" has not attribute "data-root"');
	} else {
		console.log('Element with id="main" not found');
	}
}